@@ -133,7 +133,7 @@ class ShelfModelView(sqla.ModelView):
             else:
                 return self.column_default_sort, False
         elif issubclass(self.model, OrderableMixin):
-            return 'shelf_order', True
+            return self.model.shelf_order, True
 
         return None
 
